@@ -16,7 +16,7 @@ use Pod::Simple;
 use vars qw(@ISA $VERSION);
 
 @ISA     = qw(Pod::Simple);
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 
 ###############################################################################
@@ -466,6 +466,7 @@ The currently supported formats are:
     usemod
     twiki
     tiddlywiki
+    textile
     wikipedia or mediawiki
     moinmoin
     confluence
@@ -502,6 +503,10 @@ This is the format used by TWiki wikis.  See: http://twiki.org/
 
 This is the format used by the TiddlyWiki.  See: http://www.tiddlywiki.com/
 
+=item textile
+
+The Textile markup format as used on GitHub. See: http://textile.thresholdstate.com/
+
 =item wikipedia or mediawiki
 
 This is the format used by Wikipedia and MediaWiki wikis.  See: http://www.mediawiki.org/
@@ -525,6 +530,7 @@ Any other parameters in C<new> will be passed on to the parent C<Pod::Simple> ob
 
 If you are interested in porting a new wiki format have a look at L<Pod::Simple::Wiki::Template>.
 
+The C<Pod::Simple::Wiki> git repository is: http://github.com/jmcnamara/pod-simple-wiki/
 
 =head1 SEE ALSO
 
@@ -537,14 +543,6 @@ This module also installs a C<pod2wiki> command line utility. See C<pod2wiki --h
 
 =item *
 
-Add more code, more tests and a few more users if possible.
-
-=item *
-
-Add other Wiki formats. Send requests or patches.
-
-=item *
-
 Fix some of the C<=over> edge cases. See the TODOs in the test programs.
 
 =back
@@ -564,7 +562,7 @@ Thanks to Christopher J. Madsen for several MediaWiki additions and tests.
 
 Thanks Tim Bunce for the TiddlyWiki prod and Ron Savage for the port.
 
-Thanks to David Bartle, Andrew Hobbs and Jim Renwick for conlfuence patches.
+Thanks to David Bartle, Andrew Hobbs and Jim Renwick for confluence patches.
 
 
 =head1 DISCLAIMER OF WARRANTY
@@ -574,6 +572,11 @@ Because this software is licensed free of charge, there is no warranty for the s
 In no event unless required by applicable law or agreed to in writing will any copyright holder, or any other party who may modify and/or redistribute the software as permitted by the above licence, be liable to you for damages, including any general, special, incidental, or consequential damages arising out of the use or inability to use the software (including but not limited to loss of data or data being rendered inaccurate or losses sustained by you or third parties or a failure of the software to operate with any other software), even if such holder or other party has been advised of the possibility of such damages.
 
 
+=head1 LICENSE
+
+Either the Perl Artistic Licence http://dev.perl.org/licenses/artistic.html or the GPL http://www.opensource.org/licenses/gpl-license.php
+
+
 =head1 AUTHOR
 
 John McNamara jmcnamara@cpan.org
